@@ -60,6 +60,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void onButtonPressed(PowerDevil::BackendInterface::ButtonType type);
     void powerOffButtonTriggered();
+    void powerDownButtonTriggered();
     void suspendToRam();
     void suspendToDisk();
 
@@ -75,6 +76,7 @@ private:
     bool m_externalMonitorPresent = false;
 
     uint m_powerButtonAction = 0;
+    uint m_powerDownButtonAction = 0;
     uint m_sleepButtonAction = 1;
     uint m_hibernateButtonAction = 2;
 };
